import Link from "next/link";
import { redirect } from "next/navigation";
import type { Client } from "@prisma/client";
import { AppWindow, Users } from "lucide-react";

import { getAuthorizationStats } from "@/lib/dto/authorization";
import { prisma } from "@/lib/prisma";
import { getCurrentUser } from "@/lib/session";
import { Button } from "@/components/ui/button";
import {
  Card,
  CardContent,
  CardDescription,
  CardHeader,
  CardTitle,
} from "@/components/ui/card";

interface ClientWithStats extends Client {
  stats: {
    total: number;
    activeLastMonth: number;
    newLastMonth: number;
  };
}

async function getUserClients(userId: string): Promise<ClientWithStats[]> {
  try {
    const clients = await prisma.client.findMany({
      where: { userId },
      orderBy: { createdAt: "desc" },
    });

    // 获取每个应用的授权统计
    const clientsWithStats = await Promise.all(
      clients.map(async (client) => {
        try {
          const stats = await getAuthorizationStats(client.id);
          return {
            ...client,
            stats,
          };
        } catch (error) {
          console.error(`获取应用 ${client.name} 的统计信息失败:`, error);
          return {
            ...client,
            stats: {
              total: 0,
              activeLastMonth: 0,
              newLastMonth: 0,
            },
          };
        }
      }),
    );

    return clientsWithStats;
  } catch (error) {
    console.error("获取用户应用列表失败:", error);
    return [];
  }
}

export default async function DashboardPage() {
  const user = await getCurrentUser();
  if (!user?.id) {
    redirect("/sign-in");
  }

  const clients = await getUserClients(user.id);

  return (
    <div className="mx-auto max-w-7xl px-4 py-8 sm:px-6 lg:px-8">
      <div className="mb-8 flex items-center justify-between">
        <h2 className="text-lg font-medium">我的应用</h2>
        <Link href="/dashboard/clients">
          <Button>创建新应用</Button>
        </Link>
      </div>

      <div className="grid gap-6 sm:grid-cols-2 lg:grid-cols-3">
        {clients.map((client) => (
          <Card key={client.id}>
            <CardHeader>
              <CardTitle className="flex items-center gap-2">
                <AppWindow className="h-5 w-5" />
                {client.name}
              </CardTitle>
              <CardDescription>
                {client.description || "暂无描述"}
              </CardDescription>
            </CardHeader>
            <CardContent>
              <div className="space-y-4">
                <div>
                  <div className="flex items-center gap-2">
                    <Users className="h-4 w-4 text-muted-foreground" />
                    <p className="text-sm text-muted-foreground">授权用户数</p>
                  </div>
                  <p className="mt-1 text-2xl font-bold">
                    {client.stats.total}
                  </p>
                  <div className="mt-1 flex items-center gap-4 text-sm text-muted-foreground">
                    <span>30天活跃: {client.stats.activeLastMonth}</span>
                    <span>30天新增: {client.stats.newLastMonth}</span>
                  </div>
                </div>
                <Link href={`/dashboard/clients/${client.id}`}>
                  <Button variant="outline" className="w-full">
                    查看详情
                  </Button>
                </Link>
              </div>
            </CardContent>
          </Card>
        ))}

        {clients.length === 0 && (
          <Card className="sm:col-span-2 lg:col-span-3">
            <CardHeader>
              <CardTitle>还没有应用</CardTitle>
              <CardDescription>
                创建一个新应用来开始使用 OAuth 服务
              </CardDescription>
            </CardHeader>
            <CardContent>
              <Link href="/dashboard/clients">
                <Button>创建新应用</Button>
              </Link>
            </CardContent>
          </Card>
        )}
      </div>
    </div>
  );
}
