"use client";

import { useState } from "react";
import { useRouter } from "next/navigation";
import type { Authorization } from "@prisma/client";

import {
  AlertDialog,
  AlertDialogAction,
  AlertDialogCancel,
  AlertDialogContent,
  AlertDialogDescription,
  AlertDialogFooter,
  AlertDialogHeader,
  AlertDialogTitle,
} from "@/components/ui/alert-dialog";
import { Button } from "@/components/ui/button";

interface AuthorizationStatusToggleProps {
  authorization: Authorization & {
    user: {
      username: string;
      email: string;
      name: string | null;
    };
  };
}

export function AuthorizationStatusToggle({
  authorization,
}: AuthorizationStatusToggleProps) {
  const router = useRouter();
  const [isLoading, setIsLoading] = useState(false);
  const [showDialog, setShowDialog] = useState(false);

  const handleToggle = async () => {
    try {
      setIsLoading(true);
      const response = await fetch(
        `/api/admin/authorizations/${authorization.id}/status`,
        {
          method: "POST",
          headers: {
            "Content-Type": "application/json",
          },
          body: JSON.stringify({
            enabled: !authorization.enabled,
          }),
        },
      );

      if (!response.ok) {
        throw new Error("Failed to update authorization status");
      }

      router.refresh();
    } catch (error) {
      console.error("Error updating authorization status:", error);
    } finally {
      setIsLoading(false);
      setShowDialog(false);
    }
  };

  return (
    <>
      <Button
        variant={authorization.enabled ? "destructive" : "default"}
        size="sm"
        onClick={() => setShowDialog(true)}
        disabled={isLoading}
      >
        {authorization.enabled ? "禁用" : "启用"}
      </Button>

      <AlertDialog open={showDialog} onOpenChange={setShowDialog}>
        <AlertDialogContent>
          <AlertDialogHeader>
            <AlertDialogTitle>
              确定要
              {authorization.enabled ? "禁用" : "启用"}
              用户 {authorization.user.name || authorization.user.username}{" "}
              的授权吗？
            </AlertDialogTitle>
            <AlertDialogDescription>
              {authorization.enabled
                ? "禁用后，该用户将无法使用此应用的服务。"
                : "启用后，该用户将恢复使用此应用的权限。"}
            </AlertDialogDescription>
          </AlertDialogHeader>
          <AlertDialogFooter>
            <AlertDialogCancel disabled={isLoading}>取消</AlertDialogCancel>
            <AlertDialogAction
              onClick={handleToggle}
              disabled={isLoading}
              className={authorization.enabled ? "bg-destructive" : undefined}
            >
              确定
            </AlertDialogAction>
          </AlertDialogFooter>
        </AlertDialogContent>
      </AlertDialog>
    </>
  );
}
